@@ -6,23 +6,13 @@ A lot of thanks, regarding outputting of colors, goes to the Pygments project:
 everything has been highly optimized.)
 http://pygments.org/
 """
+
 from __future__ import annotations
 
 import io
 import os
 import sys
-from typing import (
-    Callable,
-    Dict,
-    Hashable,
-    Iterable,
-    List,
-    Optional,
-    Sequence,
-    Set,
-    TextIO,
-    Tuple,
-)
+from typing import Callable, Dict, Hashable, Iterable, Sequence, TextIO, Tuple
 
 from prompt_toolkit.cursor_shapes import CursorShape
 from prompt_toolkit.data_structures import Size
@@ -532,7 +522,7 @@ class Vt100_Output(Output):
             "eterm-color",
         ):  # Not supported by the Linux console.
             self.write_raw(
-                "\x1b]2;%s\x07" % title.replace("\x1b", "").replace("\x07", "")
+                "\x1b]2;{}\x07".format(title.replace("\x1b", "").replace("\x07", ""))
             )
 
     def clear_title(self) -> None:
@@ -540,7 +530,7 @@ class Vt100_Output(Output):
 
     def erase_screen(self) -> None:
         """
-        Erases the screen with the background colour and moves the cursor to
+        Erases the screen with the background color and moves the cursor to
         home.
         """
         self.write_raw("\x1b[2J")
